#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_DEINTERLEAVE_FIRST_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_DEINTERLEAVE_FIRST_HPP_INCLUDED

#include <boost/simd/swar/include/functions/deinterleave_first.hpp>

#endif
